aboutsummaryrefslogtreecommitdiff
path: root/gdb/block.h
diff options
context:
space:
mode:
Diffstat (limited to 'gdb/block.h')
-rw-r--r--gdb/block.h33
1 files changed, 14 insertions, 19 deletions
diff --git a/gdb/block.h b/gdb/block.h
index 1741e52..0326c18 100644
--- a/gdb/block.h
+++ b/gdb/block.h
@@ -237,27 +237,22 @@ extern struct symbol *block_iterator_first (const struct block *block,
extern struct symbol *block_iterator_next (struct block_iterator *iterator);
/* Initialize ITERATOR to point at the first symbol in BLOCK whose
- SYMBOL_SEARCH_NAME is NAME, as tested using COMPARE (which must use
- the same conventions as strcmp_iw and be compatible with any
- block hashing function), and return that first symbol, or NULL
- if there are no such symbols. */
+ SYMBOL_SEARCH_NAME matches NAME, and return that first symbol, or
+ NULL if there are no such symbols. */
extern struct symbol *block_iter_match_first (const struct block *block,
- const char *name,
- symbol_compare_ftype *compare,
+ const lookup_name_info &name,
struct block_iterator *iterator);
/* Advance ITERATOR to point at the next symbol in BLOCK whose
- SYMBOL_SEARCH_NAME is NAME, as tested using COMPARE (see
- block_iter_match_first), or NULL if there are no more such symbols.
- Don't call this if you've previously received NULL from
+ SYMBOL_SEARCH_NAME matches NAME, or NULL if there are no more such
+ symbols. Don't call this if you've previously received NULL from
block_iterator_match_first or block_iterator_match_next on this
iteration. And don't call it unless ITERATOR was created by a
- previous call to block_iter_match_first with the same NAME and COMPARE. */
+ previous call to block_iter_match_first with the same NAME. */
-extern struct symbol *block_iter_match_next (const char *name,
- symbol_compare_ftype *compare,
- struct block_iterator *iterator);
+extern struct symbol *block_iter_match_next
+ (const lookup_name_info &name, struct block_iterator *iterator);
/* Search BLOCK for symbol NAME in DOMAIN. */
@@ -316,14 +311,14 @@ extern int block_find_non_opaque_type_preferred (struct symbol *sym,
(sym); \
(sym) = block_iterator_next (&(iter)))
-/* Macro to loop through all symbols with name NAME in BLOCK,
- in no particular order. ITER helps keep track of the iteration, and
- must be a struct block_iterator. SYM points to the current symbol. */
+/* Macro to loop through all symbols in BLOCK with a name that matches
+ NAME, in no particular order. ITER helps keep track of the
+ iteration, and must be a struct block_iterator. SYM points to the
+ current symbol. */
#define ALL_BLOCK_SYMBOLS_WITH_NAME(block, name, iter, sym) \
- for ((sym) = block_iter_match_first ((block), (name), \
- strcmp_iw, &(iter)); \
+ for ((sym) = block_iter_match_first ((block), (name), &(iter)); \
(sym) != NULL; \
- (sym) = block_iter_match_next ((name), strcmp_iw, &(iter)))
+ (sym) = block_iter_match_next ((name), &(iter)))
#endif /* BLOCK_H */